==> haskell-parsers-0.12.8-18-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parsers
version: 0.12.8
id: parsers-0.12.8-97PGzAI1UFX6TG9Ms0nBQY
key: parsers-0.12.8-97PGzAI1UFX6TG9Ms0nBQY
license: BSD3
copyright: Copyright (C) 2010-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/parsers/
synopsis: Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.
    .
    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".
category: Text, Parsing
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.Expression
    Text.Parser.LookAhead Text.Parser.Permutation Text.Parser.Token
    Text.Parser.Token.Highlight Text.Parser.Token.Style
abi: f528a243b289adef26af938494bec3b5
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/parsers-0.12.8
library-dirs: /usr/lib/ghc-8.2.2/site-local/parsers-0.12.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/parsers-0.12.8
hs-libraries: HSparsers-0.12.8-97PGzAI1UFX6TG9Ms0nBQY
depends:
    base-4.10.1.0 base-orphans-0.6-KoJqNefbvUAEuaR7CDOiu4
    charset-0.3.7.1-AhCg0zwbkUDBkZUyiOxjAK containers-0.5.10.2
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp
    attoparsec-0.13.2.2-3q5ERL3MW0nFqsVUGe8u15
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz transformers-0.5.2.0
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    scientific-0.3.5.3-4Af2QhuNyMzGatzrYjrxpI
    unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-orphans-0.6-KoJqNefbvUAEuaR7CDOiu4=fb09ffe63c021a5df200f5dd3f288699
             charset-0.3.7.1-AhCg0zwbkUDBkZUyiOxjAK=b495c830ee170b168cbeaec4ce237bfe
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp=b942a04aec0a266706b2e8e67bd137e3
             attoparsec-0.13.2.2-3q5ERL3MW0nFqsVUGe8u15=df3474e0e3506c6210b323c64f491baa
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             scientific-0.3.5.3-4Af2QhuNyMzGatzrYjrxpI=a27ded325e5d5959c97ff2a5817450bc
             unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G=5c8877e146af6c27c44eb74d4cb22e80
haddock-interfaces: /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html: /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parsers-0.12.8-20-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parsers
version: 0.12.8
id: parsers-0.12.8-7fxFIPGH4vw3oUn1B3hGbq
key: parsers-0.12.8-7fxFIPGH4vw3oUn1B3hGbq
license: BSD3
copyright: Copyright (C) 2010-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/parsers/
synopsis: Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.
    .
    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".
category: Text, Parsing
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.Expression
    Text.Parser.LookAhead Text.Parser.Permutation Text.Parser.Token
    Text.Parser.Token.Highlight Text.Parser.Token.Style
abi: 360c35a266c4112cac7c9827c2c25d77
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/parsers-0.12.8
library-dirs: /usr/lib/ghc-8.2.2/site-local/parsers-0.12.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/parsers-0.12.8
hs-libraries: HSparsers-0.12.8-7fxFIPGH4vw3oUn1B3hGbq
depends:
    base-4.10.1.0 base-orphans-0.6-KoJqNefbvUAEuaR7CDOiu4
    charset-0.3.7.1-AhCg0zwbkUDBkZUyiOxjAK containers-0.5.10.2
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp
    attoparsec-0.13.2.2-3yh63UNuZKU6kridcBRdzv
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz transformers-0.5.2.0
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    scientific-0.3.6.2-CyVAeaqQQPXHCT1PY3PkFn
    unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-orphans-0.6-KoJqNefbvUAEuaR7CDOiu4=fb09ffe63c021a5df200f5dd3f288699
             charset-0.3.7.1-AhCg0zwbkUDBkZUyiOxjAK=b495c830ee170b168cbeaec4ce237bfe
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp=b942a04aec0a266706b2e8e67bd137e3
             attoparsec-0.13.2.2-3yh63UNuZKU6kridcBRdzv=7ed301843f5485a15f31657e67db1a15
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             scientific-0.3.6.2-CyVAeaqQQPXHCT1PY3PkFn=b535f5c7ece7dcbe556eaf54ff052b22
             unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G=5c8877e146af6c27c44eb74d4cb22e80
haddock-interfaces: /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html: /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
